@@ -1,7 +1,5 @@
-from typing import Any, cast, Union
-
 from gitlab import types
-from gitlab.base import RESTManager, RESTObject
+from gitlab.base import RESTObject
 from gitlab.mixins import (
     CreateMixin,
     DeleteMixin,
@@ -25,7 +23,7 @@ class DeployToken(ObjectDeleteMixin, RESTObject):
     pass
 
 
-class DeployTokenManager(ListMixin, RESTManager):
+class DeployTokenManager(ListMixin[DeployToken]):
     _path = "/deploy_tokens"
     _obj_cls = DeployToken
 
@@ -34,51 +32,35 @@ class GroupDeployToken(ObjectDeleteMixin, RESTObject):
     pass
 
 
-class GroupDeployTokenManager(RetrieveMixin, CreateMixin, DeleteMixin, RESTManager):
+class GroupDeployTokenManager(
+    RetrieveMixin[GroupDeployToken],
+    CreateMixin[GroupDeployToken],
+    DeleteMixin[GroupDeployToken],
+):
     _path = "/groups/{group_id}/deploy_tokens"
     _from_parent_attrs = {"group_id": "id"}
     _obj_cls = GroupDeployToken
     _create_attrs = RequiredOptional(
-        required=(
-            "name",
-            "scopes",
-        ),
-        optional=(
-            "expires_at",
-            "username",
-        ),
+        required=("name", "scopes"), optional=("expires_at", "username")
     )
     _list_filters = ("scopes",)
     _types = {"scopes": types.ArrayAttribute}
 
-    def get(
-        self, id: Union[str, int], lazy: bool = False, **kwargs: Any
-    ) -> GroupDeployToken:
-        return cast(GroupDeployToken, super().get(id=id, lazy=lazy, **kwargs))
-
 
 class ProjectDeployToken(ObjectDeleteMixin, RESTObject):
     pass
 
 
-class ProjectDeployTokenManager(RetrieveMixin, CreateMixin, DeleteMixin, RESTManager):
+class ProjectDeployTokenManager(
+    RetrieveMixin[ProjectDeployToken],
+    CreateMixin[ProjectDeployToken],
+    DeleteMixin[ProjectDeployToken],
+):
     _path = "/projects/{project_id}/deploy_tokens"
     _from_parent_attrs = {"project_id": "id"}
     _obj_cls = ProjectDeployToken
     _create_attrs = RequiredOptional(
-        required=(
-            "name",
-            "scopes",
-        ),
-        optional=(
-            "expires_at",
-            "username",
-        ),
+        required=("name", "scopes"), optional=("expires_at", "username")
     )
     _list_filters = ("scopes",)
     _types = {"scopes": types.ArrayAttribute}
-
-    def get(
-        self, id: Union[str, int], lazy: bool = False, **kwargs: Any
-    ) -> ProjectDeployToken:
-        return cast(ProjectDeployToken, super().get(id=id, lazy=lazy, **kwargs))
